/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

/**
 * The nsIDOMStyleSheet interface is a datatype for a style sheet in
 * the Document Object Model.
 *
 * For more information on this interface please see
 * http://www.w3.org/TR/DOM-Level-2-Style
 */

[scriptable, uuid(a6cf9080-15b3-11d2-932e-00805f8add32)]
interface nsIDOMStyleSheet : nsISupports
{
  readonly attribute DOMString        type;
           attribute boolean          disabled;
  readonly attribute nsIDOMNode       ownerNode;
  readonly attribute nsIDOMStyleSheet parentStyleSheet;
  readonly attribute DOMString        href;
  readonly attribute DOMString        title;
  readonly attribute nsIDOMMediaList  media;
};
